@@ -263,4 +263,7 @@ class LibspecConverter(BaseConverter):
     def convert(self, libdoc: LibraryDoc, output: str, relative: bool):
         relative_path = Path(libdoc.source).relative_to(str(Path(".").resolve()))
         libdoc.source = str(relative_path)
+        for kw in libdoc.keywords:
+            relative_path = Path(kw.source).relative_to(str(Path(".").resolve()))
+            kw.source = relative_path
         libdoc.save(output, "LIBSPEC")
